@@ -7,12 +7,4 @@ from .espcn import ESPCN
 from .srresnet import SRResNet
 
 
-__all__ = [
-    "BaseModel",
-    "Bicubic",
-    "SRCNN",
-    "VDSR",
-    "EDSR",
-    "ESPCN",
-    "SRResNet"
-]
\ No newline at end of file
+__all__ = ["BaseModel", "Bicubic", "SRCNN", "VDSR", "EDSR", "ESPCN", "SRResNet"]
