@@ -72,10 +72,13 @@ class BaseModel(nn.Module):
             Super-Resolved image as tensor
 
         """
+        if x.ndim == 3:
+            x = x.unsqueeze(0)
+
         x = self.forward(x)
         x *= 255.0
         x = x.clamp(0, 255)
         x = x.to(torch.uint8)
-        x = x.squeeze()
-        x = x.transpose((1, 2, 0))
+        x = x.squeeze(0)
+        x = x.permute(1, 2, 0)
         return x
