@@ -1,14 +1,12 @@
 import torchvision
 
 
-__all__ = [
-    "plot_compare"
-]
+__all__ = ["plot_compare"]
 
 
 def plot_compare(sr, hr, baseline, filename):
-    """Plot Super-Resolution and High-Resolution image comparison
-
+    """
+    Plot Super-Resolution and High-Resolution image comparison
     """
     sr, hr, baseline = sr.squeeze(), hr.squeeze(), baseline.squeeze()
     grid = torchvision.utils.make_grid([hr, baseline, sr])
